California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 030 - TEMPORARY TAXES TO FUND EDUCATION. GUARANTEED LOCAL PUBLIC SAFETY FUNDING. INITIATIVE CONSTITUTIONAL AMENDMENT. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1240169 | CALIFORNIA STATE COUNCIL OF LABORERS ISSUES PAC - YES ON 30 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1349099 | YES ON 30 TO SAVE OUR SCHOOLS & NO ON 32 TO STOP CAMPAIGN FINANCE LOOPHOLES FOR CORPORATE INTERESTS, SPONSORED BY GOOD JOBS SAFE COMMUNITIES LA | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1350885 | MI FAMILIA VOTA - YES ON 30 AND 39 FOR TAX FAIRNESS AND NO ON 32 TO STOP SPECIAL EXEMPTIONS FOR CORPORATE POLITICAL SPENDING, SPONSORED BY THE CALIFORNIA STATE COUNCIL OF SERVICE EMPLOYEES | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1351245 | YES ON 30 - CALIFORNIANS FOR OPPORTUNITY - SPONSORED BY PICO CALIFORNIA AND PICO ACTION FUND | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1337625 | CALIFORNIA COALITION FOR PUBLIC HIGHER EDUCATION ISSUES COMMITTEE - YES ON PROP. 30 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1346267 | CALIFORNIA STATEWIDE LAW ENFORCEMENT ASSOCIATION ISSUES COMMITTEE, YES ON PROPOSITIONS 30 AND 35, NO ON PROPOSITION 32 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1346973 | CALIFORNIA GROCERS ASSOCIATION ISSUES COMMITTEE, YES ON PROPOSITION 30, NO ON PROPOSITION 37 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1346049 | CALIFORNIANS WORKING TOGETHER TO RESTORE & PROTECT PUBLIC SCHOOLS, UNIVERSITIES & PUBLIC SAFETY, COALITION OF EDUCATORS, SCHOOL EMPLOYEES, ...SPEAKER PEREZ & COMMUNITY ORG. TO SUPPORT PROPOSITION 30 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1343257 | BROWN; YES ON PROP. 30 - TO PROTECT OUR SCHOOLS AND PUBLIC SAFETY, A BROAD COALITION OF TEACHERS, LABOR, BUSINESS, LAW ENFORCEMENT, AND GOVERNOR | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1347688 | RECLAIM CALIFORNIA'S FUTURE - YES ON PROP. 30, NO ON PROP. 32 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1347735 | NO ON 30 - CALIFORNIANS FOR REFORMS AND JOBS, NOT TAXES, A COALITION OF TAXPAYERS AND SMALL BUSINESSES | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1344666 | PERSONAL INSURANCE FEDERATION OF CALIFORNIA ISSUES COMMITTEE, YES ON 30 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
922117 | NO NEW TAXES - A PROJECT OF THE HOWARD JARVIS TAXPAYERS ASSOCIATION | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1351941 | UNITED FOOD AND COMMERCIAL WORKERS ACTIVE BALLOT CLUB YES ON PROP. 30, NO ON PROP. 32 COMMITTEE | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
941597 | CALIFORNIA NURSES ASSOCIATION INITIATIVE POLITICAL ACTION COMMITTEE (YES ON 30 AND NO ON 32) | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
951402 | CALIFORNIA BEER & BEVERAGE DISTRIBUTORS ISSUES PAC, YES ON 30 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1347780 | GUILLEN BALLOT MEASURE COMMITTEE; PROTECT COLLEGE ACCESS FOR LOCAL STUDENTS, YES ON PROP. 30, PERALTA TRUSTEE ABEL | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
890947 | SHEET METAL WORKERS' INTERNATIONAL ASSOCIATION POLITICAL ACTION COMMITTEE, YES ON 30 AND NO ON 32 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1270683 | SMALL BUSINESS ACTION COMMITTEE PAC, NO ON 30/YES ON 32, CITIZENS FOR REFORMING SACRAMENTO | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
930207 | LABORERS POLITICAL LEAGUE EDUCATION FUND, YES ON 30 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1332378 | WORKING FOR WORKING AMERICANS SPONSORED BY UNITED BROTHERHOOD OF CARPENTERS, YES ON 30 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1344079 | EDUCATORS AND WORKING FAMILIES TO RESTORE CALIFORNIA, A COALITION OF EDUCATORS, COMMUNITY GROUPS, AND GRASSROOTS ORGANIZATIONS - YES ON PROP. 30 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1301846 | SOUTHWEST REGIONAL COUNCIL OF CARPENTERS ISSUES COMMITTEE - YES ON 30 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1283442 | CALIFORNIA RETIRED TEACHERS ASSOCIATION COMMITTEE, A COMMITTEE FOR PROPOSITION 30, SPONSORED BY THE CALIFORNIA RETIRED TEACHERS ASSOCIATION | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1348512 | GOOD JOBS LOS ANGELES COMMITTEE TO SUPPORT THE SCHOOLS AND PUBLIC SAFETY ACT OF 2012 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1333283 | CALIFORNIANS FOR INFORMED VOTING - YES ON 30, 34, 35, 36, 37, AND 39 AND NO ON 31 AND 32 SPONSORED BY BALLOT INITIATIVE STRATEGY CENTER | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1274157 | CALIFORNIA RETAILERS ASSOCIATION ISSUES COMMITTEE, A COMMITTEE TO SUPPORT PROPOSITION 30 AND PROMOTE RETAILERS' INTERESTS IN EDUCATION AND PUBLIC SAFETY | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
842149 | CONSUMER ATTORNEYS OF CALIFORNIA ISSUES POLITICAL ACTION COMMITTEE (YES ON PROPOSITION 30) | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1348981 | STUDENTS AND FAMILIES OF CALIFORNIA, YES ON 30/NO ON 32 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1348995 | ASIAN PACIFIC ENVIRONMENTAL NETWORK (APEN) ACTION'S YES ON 30 & 39, NO ON 32 COMMITTEE | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1273648 | NORTHERN CALIFORNIA DISTRICT COUNCIL OF LABORERS ISSUES PAC - YES ON 30 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1351817 | WORKING FAMILIES FOR OUR FUTURE AND BETTER SCHOOLS - YES ON 30. SPONSORED AND MAJOR FUNDING BY SERVICE EMPLOYEES INTERNATIONAL UNION | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1344800 | CALIFORNIA CALLS ACTION FUND: A COALITION OF SOCIAL JUSTICE ORGANIZATIONS FOR PROP. 30 AND AGAINST PROP. 32 | SUPPORT